@@ -27,8 +27,8 @@ class MyWhatify:
     #######    API's      #######
     #############################
     user_token = None
-    magento_magento2url = None
-    magento_headers = None
+    magento_magento2url = ''
+    magento_headers = ''
 
     @classmethod
     def __init__(cls):
@@ -173,15 +173,23 @@ class MyWhatify:
         :param only_total:
         :return:
         '''
+        ret_json = None
+        retval = None
         base_url = cls.magento_magento2url + '?'
         base_vars = ['table', 'page', 'limit', 'addtotal', 'onlytotal']
         for var in base_vars:
             if locals().get(var) is not None:
                 base_url += str(var) + '=' + str(locals().get(var)) + '&'
         base_url = base_url[:-1]
-
-        ret_json = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
-        retval = pd.DataFrame.from_dict(ret_json['data']['rows'], orient='columns')
+        try:
+            ret_json = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
+        except Exception as e:
+            logging.info('Failed to get data from api, got error: ' + str(e))
+        if ret_json:
+            try:
+                retval = pd.DataFrame.from_dict(ret_json['data']['rows'], orient='columns')
+            except Exception as ex:
+                logging.info('Failed to convert data into DataFrame, got error: ' + str(ex))
         return retval
 
     #############################
